ErrorToken class

A token containing error information.

Inheritance

Constructors

ErrorToken(int kind, FileSpan span, String? message)

Properties

end → int
The end offset of this token.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
kind → int
A member of TokenKind specifying what kind of token this is.
finalinherited
message ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → FileSpan
The location where this token was parsed from.
finalinherited
start → int
The start offset of this token.
no setterinherited
text → String
Returns the source text corresponding to this Token.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns a pretty representation of this token for error messages.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited