Rgba class

Rgba class for users that want to interact with a color as a RGBA value.

Implemented types

Constructors

Rgba(int red, int green, int blue, [num? alpha])
Rgba.fromArgbValue(num value)
factory
Rgba.fromColor(Color color)
factory
Rgba.fromHsla(Hsla hsla)
factory
Rgba.fromString(String hexValue)
factory

Properties

a → num?
final
argbValue → int
Return argb as a value (int).
no setteroverride
b → int
final
color → Color
no setter
cssExpression → String
Returns the expression part of a CSS declaration. Declaration is:
no setter
g → int
final
hashCode → int
The hash code for this object.
no setteroverride
hsla → Hsla
no setter
r → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

darker(num amount) → Rgba
lighter(num amount) → Rgba
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHexArgbString() → String
Canonical form for color #rrggbb with alpha blending (0.0 == full transparency and 1.0 == fully opaque). If _argb length is 6 it's an rrggbb otherwise it's aarrggbb.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override