Token class

A single token in the Dart language.

Implementers

Constructors

Token(int kind, FileSpan span)

Properties

end → int
The end offset of this token.
no setter
hashCode → int
The hash code for this object.
no setterinherited
kind → int
A member of TokenKind specifying what kind of token this is.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → FileSpan
The location where this token was parsed from.
final
start → int
The start offset of this token.
no setter
text → String
Returns the source text corresponding to this Token.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns a pretty representation of this token for error messages.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited