TokenKind class

Constructors

TokenKind()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

colorValue(Map<String, Object> entry) → int
Return RGB value as int from a color entry in _EXTENDED_COLOR_NAMES.
decimalToHex(int number, [int minDigits = 1]) → String
hexToColorName(Object hexValue) → String?
idToValue(Iterable<Object?> identList, int tokenId) → String?
isIdentifier(int kind) → bool
isKindIdentifier(int kind) → bool
isPredefinedName(String name) → bool
Check if a name is a pre-defined CSS name.
kindToString(int kind) → String
matchColorName(String text) → Map<String, Object>?
Match color name, case insensitive match and return the associated color entry from _EXTENDED_COLOR_NAMES list, return null if not found.
matchDirectives(String text, int offset, int length) → int
Return the token that matches the directive name found.
matchList(List<Map<String, dynamic>> identList, String tokenField, String text, int offset, int length) → int
Return the token that matches the unit ident found.
matchMarginDirectives(String text, int offset, int length) → int
Return the token that matches the margin directive name found.
matchMediaOperator(String text, int offset, int length) → int
Return the token that matches the media operator found.
matchUnits(String text, int offset, int length) → int
Return the token that matches the unit ident found.
unitToString(int unitTokenToFind) → String?
Return the unit token as its pretty name.

Constants

AMPERSAND → const int
ASCII_UPPER_A → const int
ASCII_UPPER_Z → const int
ASTERISK → const int
AT → const int
ATTRIBUTE_NAME → const int
BACKSLASH → const int
BANG → const int
CARET → const int
CDATA_END → const int
CDATA_START → const int
CLASS_NAME → const int
COLON → const int
COMBINATOR_DESCENDANT → const int
COMBINATOR_GREATER → const int
COMBINATOR_NONE → const int
COMBINATOR_PLUS → const int
COMBINATOR_TILDE → const int
COMMA → const int
COMMENT → const int
TokenKind representing comment tokens.
DASH_MATCH → const int
DIRECTIVE_CHARSET → const int
DIRECTIVE_CONTENT → const int
DIRECTIVE_EXTEND → const int
DIRECTIVE_FONTFACE → const int
DIRECTIVE_HOST → const int
DIRECTIVE_IMPORT → const int
DIRECTIVE_INCLUDE → const int
DIRECTIVE_KEYFRAMES → const int
DIRECTIVE_MEDIA → const int
DIRECTIVE_MIXIN → const int
DIRECTIVE_MOZ_DOCUMENT → const int
DIRECTIVE_MOZ_KEYFRAMES → const int
DIRECTIVE_MS_KEYFRAMES → const int
DIRECTIVE_MS_VIEWPORT → const int
DIRECTIVE_NAMESPACE → const int
DIRECTIVE_NONE → const int
DIRECTIVE_O_KEYFRAMES → const int
DIRECTIVE_PAGE → const int
DIRECTIVE_STYLET → const int
DIRECTIVE_SUPPORTS → const int
DIRECTIVE_VIEWPORT → const int
DIRECTIVE_WEB_KIT_KEYFRAMES → const int
DOLLAR → const int
DOT → const int
DOUBLE → const int
TokenKind representing double tokens.
DOUBLE_QUOTE → const int
ELEMENT_NAME → const int
END_OF_FILE → const int
EQUALS → const int
ERROR → const int
TokenKind representing error tokens.
GREATER → const int
HASH → const int
HASH_NAME → const int
HEX_INTEGER → const int
TokenKind representing hex integer tokens.
HEX_NUMBER → const int
HEX_RANGE → const int
HTML_COMMENT → const int
IDENTIFIER → const int
IMPORTANT → const int
INCLUDES → const int
INCOMPLETE_COMMENT → const int
TokenKind representing incomplete comment tokens.
INCOMPLETE_STRING → const int
TokenKind representing incomplete string tokens.
INTEGER → const int
TokenKind representing integer tokens.
LBRACE → const int
LBRACK → const int
LESS → const int
LPAREN → const int
MARGIN_DIRECTIVE_BOTTOMCENTER → const int
MARGIN_DIRECTIVE_BOTTOMLEFT → const int
MARGIN_DIRECTIVE_BOTTOMLEFTCORNER → const int
MARGIN_DIRECTIVE_BOTTOMRIGHT → const int
MARGIN_DIRECTIVE_BOTTOMRIGHTCORNER → const int
MARGIN_DIRECTIVE_LEFTBOTTOM → const int
MARGIN_DIRECTIVE_LEFTMIDDLE → const int
MARGIN_DIRECTIVE_LEFTTOP → const int
MARGIN_DIRECTIVE_RIGHTBOTTOM → const int
MARGIN_DIRECTIVE_RIGHTMIDDLE → const int
MARGIN_DIRECTIVE_RIGHTTOP → const int
MARGIN_DIRECTIVE_TOPCENTER → const int
MARGIN_DIRECTIVE_TOPLEFT → const int
MARGIN_DIRECTIVE_TOPLEFTCORNER → const int
MARGIN_DIRECTIVE_TOPRIGHT → const int
MARGIN_DIRECTIVE_TOPRIGHTCORNER → const int
MARGIN_DIRECTIVES → const List<Map<String, Object>>
MEDIA_OP_AND → const int
MEDIA_OP_NOT → const int
MEDIA_OP_ONLY → const int
MEDIA_OPERATORS → const List<Map<String, Object>>
MINUS → const int
NAMESPACE → const int
NEGATION → const int
NEWLINE → const int
NO_MATCH → const int
NUMBER → const int
PERCENT → const int
PLUS → const int
PREFIX_MATCH → const int
PRIVATE_NAME → const int
PSEUDO_CLASS_NAME → const int
PSEUDO_ELEMENT_NAME → const int
RBRACE → const int
RBRACK → const int
RETURN → const int
RPAREN → const int
SELECTOR_EXPRESSION → const int
SEMICOLON → const int
SINGLE_QUOTE → const int
SLASH → const int
SPACE → const int
STRING → const int
STRING_PART → const int
SUBSTRING_MATCH → const int
SUFFIX_MATCH → const int
TAB → const int
TILDE → const int
UNARY_OP_NONE → const int
UNICODE_RANGE → const int
UNIT_ANGLE_DEG → const int
UNIT_ANGLE_GRAD → const int
UNIT_ANGLE_RAD → const int
UNIT_ANGLE_TURN → const int
UNIT_CH → const int
UNIT_EM → const int
UNIT_EX → const int
UNIT_FRACTION → const int
UNIT_FREQ_HZ → const int
UNIT_FREQ_KHZ → const int
UNIT_LENGTH_CM → const int
UNIT_LENGTH_IN → const int
UNIT_LENGTH_MM → const int
UNIT_LENGTH_PC → const int
UNIT_LENGTH_PT → const int
UNIT_LENGTH_PX → const int
UNIT_LH → const int
UNIT_PERCENT → const int
UNIT_REM → const int
UNIT_RESOLUTION_DPCM → const int
UNIT_RESOLUTION_DPI → const int
UNIT_RESOLUTION_DPPX → const int
UNIT_RLH → const int
UNIT_TIME_MS → const int
UNIT_TIME_S → const int
UNIT_VIEWPORT_VH → const int
UNIT_VIEWPORT_VMAX → const int
UNIT_VIEWPORT_VMIN → const int
UNIT_VIEWPORT_VW → const int
UNUSED → const int
VAR_DEFINITION → const int
VAR_USAGE → const int
WHITESPACE → const int
TokenKind representing whitespace tokens.