Tokenizer class

Inheritance

Constructors

Tokenizer(SourceFile file, String text, bool skipWhitespace, [int index = 0])

Properties

CDATA_NAME → List<int>
CDATA keyword.
final
hashCode → int
The hash code for this object.
no setterinherited
inSelector ↔ bool
Changes tokenization when in selectors. If true, it prevents identifiers from being treated as units. This would break things like ":lang(fr)" or the HTML (unknown) tag name "px", which is legal to use in a selector.
getter/setter pairinherited
inSelectorExpression ↔ bool
Changes tokenization when in a pseudo function expression. If true then minus signs are handled as operators instead of identifiers.
getter/setter pairinherited
mark → TokenizerState
Snapshot of Tokenizer scanning state.
no setterinherited
QUESTION_MARK → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
UNICODE_LOWER_U → int
final
UNICODE_PLUS → int
final
UNICODE_U → int
U+ prefix for unicode characters.
final

Methods

eatDigits() → void
inherited
eatHexDigits(int end) → void
eatQuestionMarks() → void
finishDot() → Token
inherited
finishHexNumber() → Token
finishHtmlComment() → Token
finishIdentifier() → Token
finishMultiLineComment() → Token
override
finishMultilineRawString(int quote) → Token
inherited
finishMultilineString(int quote) → Token
inherited
finishNumber() → Token
override
finishNumberExtra(int kind) → Token
inherited
finishRawString(int quote) → Token
inherited
finishString(int quote) → Token
inherited
finishStringBody(int quote) → Token
inherited
finishUnicodeRange() → Token
finishWhitespace() → Token
inherited
getIdentifierKind() → int
override
makeIEFilter(int start, int end) → Token
inherited
maybeEatDigit() → bool
maybeEatHexDigit() → bool
maybeEatQuestionMark() → bool
next({bool unicodeRange = false}) → Token
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readEscapeSequence() → int
inherited
readHex([int? hexLength]) → int
inherited
restore(TokenizerState markedData) → void
Restore Tokenizer scanning state.
inherited
toString() → String
A string representation of this object.
inherited
varDef(int ch) → bool
varUsage(int ch) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited