TokenizerBase class abstract

The base class for our tokenizer. The hand coded parts are in this file, with the generated parts in the subclass Tokenizer.

Implementers

Constructors

TokenizerBase(SourceFile _file, String _text, bool _inString, [int _index = 0])

Properties

hashCode → int
The hash code for this object.
no setterinherited
inSelector ↔ bool
Changes tokenization when in selectors. If true, it prevents identifiers from being treated as units. This would break things like ":lang(fr)" or the HTML (unknown) tag name "px", which is legal to use in a selector.
getter/setter pair
inSelectorExpression ↔ bool
Changes tokenization when in a pseudo function expression. If true then minus signs are handled as operators instead of identifiers.
getter/setter pair
mark → TokenizerState
Snapshot of Tokenizer scanning state.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

eatDigits() → void
finishDot() → Token
finishMultiLineComment() → Token
finishMultilineRawString(int quote) → Token
finishMultilineString(int quote) → Token
finishNumber() → Token
finishNumberExtra(int kind) → Token
finishRawString(int quote) → Token
finishString(int quote) → Token
finishStringBody(int quote) → Token
finishWhitespace() → Token
getIdentifierKind() → int
makeIEFilter(int start, int end) → Token
next() → Token
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readEscapeSequence() → int
readHex([int? hexLength]) → int
restore(TokenizerState markedData) → void
Restore Tokenizer scanning state.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited