TokenizerHelpers class

Static helper methods.

Constructors

TokenizerHelpers()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isDigit(int c) → bool
isHexDigit(int c) → bool
isIdentifierPart(int c) → bool
isIdentifierPartExpr(int c) → bool
Pseudo function expressions identifiers can't have a minus sign.
isIdentifierStart(int c) → bool
isIdentifierStartExpr(int c) → bool
Pseudo function expressions identifiers can't have a minus sign.