DartStyleExpression class abstract

Inheritance
Implementers

Constructors

DartStyleExpression(int? _styleType, SourceSpan? span)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isBorder → bool
no setter
isBoxExpression → bool
no setter
isFont → bool
no setter
isHeight → bool
no setter
isMargin → bool
no setter
isPadding → bool
no setter
isUnknown → bool
no setter
isWidth → bool
no setter
priority ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → SourceSpan
The source code this TreeNode represents.
no setteroverride

Methods

clone() → TreeNode
inherited
isSame(DartStyleExpression other) → bool
merged(DartStyleExpression newDartExpr) → DartStyleExpression?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
A multiline string showing the node and its children.
inherited
toString() → String
A string representation of this object.
inherited
visit(VisitorBase visitor) → dynamic
Classic double-dispatch visitor for implementing passes.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

borderStyle → const int
fontStyle → const int
heightStyle → const int
marginStyle → const int
paddingStyle → const int
unknownType → const int
widthStyle → const int