Declaration class

Inheritance
Implementers

Constructors

Declaration(Identifier? _property, Expression? expression, DartStyleExpression? dartStyle, SourceSpan? span, {bool important = false, bool ie7 = false})

Properties

dartStyle ↔ DartStyleExpression?
Style exposed to Dart.
getter/setter pair
expression → Expression?
final
hasDartStyle → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
important → bool
final
isIE7 → bool
IE CSS hacks that can only be read by a particular IE version. 7 implies IE 7 or older property (e.g., *background: blue;)
final
property → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → SourceSpan
The source code this TreeNode represents.
no setteroverride

Methods

clone() → Declaration
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
A multiline string showing the node and its children.
inherited
toString() → String
A string representation of this object.
inherited
visit(VisitorBase visitor) → dynamic
Classic double-dispatch visitor for implementing passes.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited