MarginExpression class

Inheritance

Constructors

MarginExpression(SourceSpan? span, {num? top, num? right, num? bottom, num? left})
Margin expression ripped apart.
MarginExpression.boxEdge(SourceSpan? span, BoxEdge? box)
MarginExpression.merge(MarginExpression x, MarginExpression y)
Merge the two MarginExpressions and return the result.
factory

Properties

box → BoxEdge?
finalinherited
formattedBoxEdge → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isBorder → bool
no setterinherited
isBoxExpression → bool
no setterinherited
isFont → bool
no setterinherited
isHeight → bool
no setterinherited
isMargin → bool
no setterinherited
isPadding → bool
no setterinherited
isUnknown → bool
no setterinherited
isWidth → bool
no setterinherited
priority ↔ int?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → SourceSpan
The source code this TreeNode represents.
no setterinherited

Methods

clone() → MarginExpression
override
isSame(DartStyleExpression other) → bool
inherited
merged(DartStyleExpression newDartExpr) → MarginExpression?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
A multiline string showing the node and its children.
inherited
toString() → String
A string representation of this object.
inherited
visit(VisitorBase visitor) → dynamic
Classic double-dispatch visitor for implementing passes.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited