MediaExpression class

MediaExpression grammar:

'(' S* media_feature S* [ ':' S* expr ]? ')' S*
Inheritance

Constructors

MediaExpression(bool andOperator, Identifier _mediaFeature, Expressions exprs, SourceSpan? span)

Properties

andOperator → bool
final
exprs → Expressions
final
hashCode → int
The hash code for this object.
no setterinherited
mediaFeature → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → SourceSpan
The source code this TreeNode represents.
no setteroverride

Methods

clone() → MediaExpression
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
A multiline string showing the node and its children.
inherited
toString() → String
A string representation of this object.
inherited
visit(VisitorBase visitor) → dynamic
Classic double-dispatch visitor for implementing passes.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited