NamespaceSelector class

Inheritance

Constructors

NamespaceSelector(dynamic _namespace, Object name, SourceSpan? span)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNamespaceWildcard → bool
no setter
isThis → bool
no setterinherited
isWildcard → bool
no setterinherited
name → String
no setterinherited
nameAsSimpleSelector → SimpleSelector?
no setter
namespace → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → SourceSpan?
The source code this TreeNode represents.
finalinherited

Methods

clone() → NamespaceSelector
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
A multiline string showing the node and its children.
inherited
toString() → String
A string representation of this object.
override
visit(VisitorBase visitor) → dynamic
Classic double-dispatch visitor for implementing passes.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited