SimpleSelectorSequence class

Inheritance

Constructors

SimpleSelectorSequence(SimpleSelector simpleSelector, SourceSpan? span, [int combinator = TokenKind.COMBINATOR_NONE])

Properties

combinator ↔ int
+, >, ~, NONE
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isCombinatorDescendant → bool
no setter
isCombinatorGreater → bool
no setter
isCombinatorNone → bool
no setter
isCombinatorPlus → bool
no setter
isCombinatorTilde → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
simpleSelector → SimpleSelector
final
span → SourceSpan?
The source code this TreeNode represents.
finalinherited

Methods

clone() → SimpleSelectorSequence
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
A multiline string showing the node and its children.
inherited
toString() → String
A string representation of this object.
override
visit(VisitorBase visitor) → dynamic
Classic double-dispatch visitor for implementing passes.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited