UnicodeRangeTerm class

Inheritance

Constructors

UnicodeRangeTerm(String? first, String? second, SourceSpan? span)

Properties

first → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hasSecond → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → String?
final
span → SourceSpan?
The source code this TreeNode represents.
finalinherited

Methods

clone() → UnicodeRangeTerm
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDebugString() → String
A multiline string showing the node and its children.
inherited
toString() → String
A string representation of this object.
inherited
visit(VisitorBase visitor) → dynamic
Classic double-dispatch visitor for implementing passes.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited